@@ -21,7 +21,7 @@ the arguments to the Chart class and calling the proper functions.
 from __future__ import absolute_import
 
 from ...models import Range1d
-from ...core.properties import Bool, Int
+from ...core.properties import Bool, Int, Either, Float, List
 
 from ..builder import create_and_build
 from .bar_builder import BarBuilder
@@ -48,7 +48,9 @@ def Histogram(data, values=None, label=None, color=None, agg="count",
     the variable by a categorical variable.
 
     Args:
-      data (:ref:`userguide_charts_data_types`): the data source for the chart
+      data (:ref:`userguide_charts_data_types`): the data source for the chart.
+        Must consist of at least 2 values. If all values are equal, the result
+        is a single bin with arbitrary width.
       values (str, optional): the values to use for producing the histogram using
         table-like input data
       label (str or list(str), optional): the categorical variable to use for creating
@@ -58,6 +60,8 @@ def Histogram(data, values=None, label=None, color=None, agg="count",
         histogram, or explicit color as a string.
       agg (str, optional): how to aggregate the bins. Defaults to "count".
       bins (int, optional): the number of bins to use. Defaults to None to auto select.
+      density (bool, optional): whether to normalize the histogram. Defaults to False.
+
       **kw:
 
     In addition to the parameters specific to this chart,
@@ -71,15 +75,16 @@ def Histogram(data, values=None, label=None, color=None, agg="count",
     .. bokeh-plot::
         :source-position: above
 
+        from bokeh.charts import Histogram, output_file, show
+        from bokeh.layouts import row
         from bokeh.sampledata.autompg import autompg as df
-        from bokeh.charts import Histogram, output_file, show, hplot
 
         hist = Histogram(df, values='mpg', title="Auto MPG Histogram", plot_width=400)
         hist2 = Histogram(df, values='mpg', label='cyl', color='cyl', legend='top_right',
                           title="MPG Histogram by Cylinder Count", plot_width=400)
 
         output_file('hist.html')
-        show(hplot(hist, hist2))
+        show(row(hist, hist2))
     """
     if continuous_range and not isinstance(continuous_range, Range1d):
         raise ValueError(
@@ -109,20 +114,26 @@ class HistogramBuilder(BarBuilder):
 
     """
 
-    bins = Int(default=None, help="""
-    Number of bins to use for the histogram. (default: None
-    (use Freedman-Diaconis rule)
+    bins = Either(List(Float), Int, default=None, help="""
+    If bins is an int, it defines the number of equal-width bins in the
+    given range. If bins is a sequence, it defines the
+    bin edges, including the rightmost edge, allowing for non-uniform
+    bin widths.
+
+    (default: None, use Freedman-Diaconis rule)
     """)
 
-    density = Bool(True, help="""
-    Whether to normalize the histogram. (default: True)
+    density = Bool(False, help="""
+    Whether to normalize the histogram.
 
     If True, the result is the value of the probability *density* function
     at the bin, normalized such that the *integral* over the range is 1. If
     False, the result will contain the number of samples in each bin.
 
-    For more info check ``numpy.histogram`` function documentation.
+    For more info check :class:`~bokeh.charts.glyphs.HistogramGlyph`
+    documentation.
 
+    (default: False)
     """)
 
     glyph = HistogramGlyph
@@ -136,7 +147,7 @@ class HistogramBuilder(BarBuilder):
 
     def get_extra_args(self):
         """Build kwargs that are unique to the histogram builder."""
-        return dict(bin_count=self.bins)
+        return dict(bins=self.bins, density=self.density)
 
     def _apply_inferred_index(self):
         # ignore this for now, unless histogram later adds handling of indexed data
@@ -152,7 +163,7 @@ class HistogramBuilder(BarBuilder):
         y_max = max([comp_glyph.y_max for comp_glyph in self.comp_glyphs])
         y_min = min([comp_glyph.y_min for comp_glyph in self.comp_glyphs])
 
-        x_buffer = ((x_max + x_min)/2.0)*0.1
+        x_buffer = ((x_max + x_min)/2.0)*0.05
 
         self.x_range = Range1d(start=x_min - x_buffer, end=x_max + x_buffer)
 
