@@ -4,15 +4,18 @@ Bokeh plots
 """
 from __future__ import absolute_import
 
-from ..properties import Int, Float, String, Enum, Bool, Datetime, Auto, Instance, Tuple, Either, Include
-from ..mixins import LineProps, TextProps
-from ..enums import Location
+from ..core.properties import abstract
+from ..core.properties import (Int, Float, String, Enum, Bool, Datetime, Auto, Instance,
+                          Tuple, Either, Include, Override)
+from ..core.property_mixins import LineProps, TextProps
+from ..core.enums import Location
 
 from .renderers import GuideRenderer
 from .tickers import Ticker, BasicTicker, LogTicker, CategoricalTicker, DatetimeTicker
-from .formatters import (TickFormatter, BasicTickFormatter, LogTickFormatter, 
+from .formatters import (TickFormatter, BasicTickFormatter, LogTickFormatter,
                          CategoricalTickFormatter, DatetimeTickFormatter)
 
+@abstract
 class Axis(GuideRenderer):
     """ A base class that defines common properties for all axis types.
     ``Axis`` is not generally useful to instantiate on its own.
@@ -23,10 +26,6 @@ class Axis(GuideRenderer):
     Ability to hide the entire axis from the plot.
     """)
 
-    location = Either(Auto, Enum(Location), help="""
-    Where should labels and ticks be located in relation to the axis rule.
-    """)
-
     bounds = Either(Auto, Tuple(Float, Float), Tuple(Datetime, Datetime), help="""
     Bounds for the rendered axis. If unset, the axis will span the
     entire plot in the given dimension.
@@ -53,7 +52,7 @@ class Axis(GuideRenderer):
     of ticks.
     """)
 
-    axis_label = String(help="""
+    axis_label = String(default='', help="""
     A text label for the axis, displayed parallel to the axis rule.
 
     .. note::
@@ -62,7 +61,7 @@ class Axis(GuideRenderer):
 
     """)
 
-    axis_label_standoff = Int(help="""
+    axis_label_standoff = Int(default=5, help="""
     The distance in pixels that the axis labels should be offset
     from the tick labels.
     """)
@@ -71,7 +70,11 @@ class Axis(GuideRenderer):
     The %s of the axis label.
     """)
 
-    major_label_standoff = Int(help="""
+    axis_label_text_font_size = Override(default={'value': "10pt"})
+
+    axis_label_text_font_style = Override(default="italic")
+
+    major_label_standoff = Int(default=5, help="""
     The distance in pixels that the major tick labels should be
     offset from the associated ticks.
     """)
@@ -85,6 +88,12 @@ class Axis(GuideRenderer):
     The %s of the major tick labels.
     """)
 
+    major_label_text_align = Override(default="center")
+
+    major_label_text_baseline = Override(default="alphabetic")
+
+    major_label_text_font_size = Override(default={'value': "8pt"})
+
     axis_props = Include(LineProps, help="""
     The %s of the axis line.
     """)
@@ -93,12 +102,12 @@ class Axis(GuideRenderer):
     The %s of the major ticks.
     """)
 
-    major_tick_in = Int(help="""
+    major_tick_in = Int(default=2, help="""
     The distance in pixels that major ticks should extend into the
     main plot area.
     """)
 
-    major_tick_out = Int(help="""
+    major_tick_out = Int(default=6, help="""
     The distance in pixels that major ticks should extend out of the
     main plot area.
     """)
@@ -107,18 +116,19 @@ class Axis(GuideRenderer):
     The %s of the minor ticks.
     """)
 
-    minor_tick_in = Int(help="""
+    minor_tick_in = Int(default=0, help="""
     The distance in pixels that minor ticks should extend into the
     main plot area.
     """)
 
-    minor_tick_out = Int(help="""
+    minor_tick_out = Int(default=4, help="""
     The distance in pixels that major ticks should extend out of the
     main plot area.
     """)
 
+@abstract
 class ContinuousAxis(Axis):
-    """ A base class for all numeric, non-categorica axes types.
+    """ A base class for all numeric, non-categorical axes types.
     ``ContinuousAxis`` is not generally useful to instantiate on its own.
 
     """
@@ -129,37 +139,27 @@ class LinearAxis(ContinuousAxis):
     linear scale. Configured with a ``BasicTickFormatter`` by default.
 
     """
-    def __init__(self, ticker=None, formatter=None, **kwargs):
-        if ticker is None:
-            ticker = BasicTicker()
-        if formatter is None:
-            formatter = BasicTickFormatter()
-        super(LinearAxis, self).__init__(ticker=ticker, formatter=formatter, **kwargs)
+    ticker = Override(default=lambda: BasicTicker())
+
+    formatter = Override(default=lambda: BasicTickFormatter())
 
 class LogAxis(ContinuousAxis):
     """ An axis that picks nice numbers for tick locations on a
     log scale. Configured with a ``LogTickFormatter`` by default.
 
     """
+    ticker = Override(default=lambda: LogTicker())
 
-    def __init__(self, ticker=None, formatter=None, **kwargs):
-        if ticker is None:
-            ticker = LogTicker(num_minor_ticks=10)
-        if formatter is None:
-            formatter = LogTickFormatter(ticker=ticker)
-        super(LogAxis, self).__init__(ticker=ticker, formatter=formatter, **kwargs)
+    formatter = Override(default=lambda: LogTickFormatter())
 
 class CategoricalAxis(Axis):
     """ An axis that picks evenly spaced tick locations for a
     collection of categories/factors.
 
     """
-    def __init__(self, ticker=None, formatter=None, **kwargs):
-        if ticker is None:
-            ticker = CategoricalTicker()
-        if formatter is None:
-            formatter = CategoricalTickFormatter()
-        super(CategoricalAxis, self).__init__(ticker=ticker, formatter=formatter, **kwargs)
+    ticker = Override(default=lambda: CategoricalTicker())
+
+    formatter = Override(default=lambda: CategoricalTickFormatter())
 
 class DatetimeAxis(LinearAxis):
     """ An LinearAxis that picks nice numbers for tick locations on
@@ -167,22 +167,7 @@ class DatetimeAxis(LinearAxis):
     default.
 
     """
-    axis_label = String("date", help="""
-    DateTime ``axis_label`` defaults to "date".
-    """)
 
-    # TODO: (bev) this should be an Enum, if it is exposed at all
-    scale = String("time")
+    ticker = Override(default=lambda: DatetimeTicker())
 
-    num_labels = Int(8)
-
-    char_width = Int(10)
-
-    fill_ratio = Float(0.3)
-
-    def __init__(self, ticker=None, formatter=None, **kwargs):
-        if ticker is None:
-            ticker = DatetimeTicker()
-        if formatter is None:
-            formatter = DatetimeTickFormatter()
-        super(DatetimeAxis, self).__init__(ticker=ticker, formatter=formatter, **kwargs)
+    formatter = Override(default=lambda: DatetimeTickFormatter())
