@@ -5,64 +5,56 @@ with data columns from data sources.
 """
 from __future__ import absolute_import
 
-from ..enums import Direction, Anchor
-from ..mixins import FillProps, LineProps, TextProps
-from ..plot_object import PlotObject
-from ..properties import (abstract, AngleSpec, Bool, DistanceSpec, Enum, Float,
-                          Include, Instance, NumberSpec, StringSpec)
+from ..core.enums import Direction, Anchor
+from ..core.property_mixins import FillProps, LineProps, TextProps
+from ..model import Model
+from ..core.properties import (abstract, AngleSpec, Bool, DistanceSpec, Enum, Float,
+                          Include, Instance, Int, NumberSpec, StringSpec)
 
-from .mappers import LinearColorMapper
+from .mappers import ColorMapper, LinearColorMapper
 
 @abstract
-class Glyph(PlotObject):
-    """ Base class for all glyphs/marks/geoms/whatever-you-call-'em in Bokeh.
+class Glyph(Model):
+    """ Base class for all glyph models. """
 
-    """
-
-    visible = Bool(help="""
+    visible = Bool(True, help="""
     Whether the glyph should render or not.
     """)
 
 class AnnularWedge(Glyph):
-    """ Render annular wedges.
+    """ Render annular wedges. """
 
-    Example
-    -------
+    __example__ = "tests/glyphs/AnnularWedge.py"
 
-    .. bokeh-plot:: ../tests/glyphs/AnnularWedge.py
-        :source-position: none
+    # a canonical order for positional args that can be used for any
+    # functions derived from this class
+    _args = ('x', 'y', 'inner_radius', 'outer_radius', 'start_angle', 'end_angle', 'direction')
 
-    *source:* `tests/glyphs/AnnularWedge.py <https://github.com/bokeh/bokeh/tree/master/tests/glyphs/AnnularWedge.py>`_
-
-    """
-
-    x = NumberSpec("x", help="""
+    x = NumberSpec(help="""
     The x-coordinates of the center of the annular wedges.
     """)
 
-    y = NumberSpec("y", help="""
+    y = NumberSpec(help="""
     The y-coordinates of the center of the annular wedges.
     """)
 
-    inner_radius = DistanceSpec("inner_radius", help="""
+    inner_radius = DistanceSpec(help="""
     The inner radii of the annular wedges.
     """)
 
-    outer_radius = DistanceSpec("outer_radius", help="""
+    outer_radius = DistanceSpec(help="""
     The outer radii of the annular wedges.
     """)
 
-    start_angle = AngleSpec("start_angle", help="""
-    The angles to start the annular wedges, in radians, as measured from
-    the horizontal.
+    start_angle = AngleSpec(help="""
+    The angles to start the annular wedges, as measured from the horizontal.
     """)
 
-    end_angle = AngleSpec("end_angle", help="""
-    The angles to end the annular wedges, in radians, as measured from
-    the horizontal.
+    end_angle = AngleSpec(help="""
+    The angles to end the annular wedges, as measured from the horizontal.
     """)
 
-    direction = Enum(Direction, help="""
+    direction = Enum(Direction, default=Direction.anticlock, help="""
     Which direction to stroke between the start and end angles.
     """)
 
@@ -75,31 +67,27 @@ class AnnularWedge(Glyph):
     """)
 
 class Annulus(Glyph):
-    """ Render annuli.
+    """ Render annuli. """
 
-    Example
-    -------
+    __example__ = "tests/glyphs/Annulus.py"
 
-    .. bokeh-plot:: ../tests/glyphs/Annulus.py
-        :source-position: none
+    # a canonical order for positional args that can be used for any
+    # functions derived from this class
+    _args = ('x', 'y', 'inner_radius', 'outer_radius')
 
-    *source:* `tests/glyphs/Annulus.py <https://github.com/bokeh/bokeh/tree/master/tests/glyphs/Annulus.py>`_
-
-    """
-
-    x = NumberSpec("x", help="""
+    x = NumberSpec(help="""
     The x-coordinates of the center of the annuli.
     """)
 
-    y = NumberSpec("y", help="""
+    y = NumberSpec(help="""
     The y-coordinates of the center of the annuli.
     """)
 
-    inner_radius = DistanceSpec("inner_radius", help="""
+    inner_radius = DistanceSpec(help="""
     The inner radii of the annuli.
     """)
 
-    outer_radius = DistanceSpec("outer_radius", help="""
+    outer_radius = DistanceSpec(help="""
     The outer radii of the annuli.
     """)
 
@@ -112,41 +100,38 @@ class Annulus(Glyph):
     """)
 
 class Arc(Glyph):
-    """ Render arcs.
+    """ Render arcs. """
 
-    Example
-    -------
+    __example__ = "tests/glyphs/Arc.py"
 
-    .. bokeh-plot:: ../tests/glyphs/Arc.py
-        :source-position: none
+    # a canonical order for positional args that can be used for any
+    # functions derived from this class
+    _args = ('x', 'y', 'radius', 'start_angle', 'end_angle', 'direction')
 
-    *source:* `tests/glyphs/Arc.py <https://github.com/bokeh/bokeh/tree/master/tests/glyphs/Arc.py>`_
-
-    """
-
-    x = NumberSpec("x", help="""
+    x = NumberSpec(help="""
     The x-coordinates of the center of the arcs.
     """)
 
-    y = NumberSpec("y", help="""
+    y = NumberSpec(help="""
     The y-coordinates of the center of the arcs.
     """)
 
-    radius = DistanceSpec("radius", help="""
+    radius = DistanceSpec(help="""
     Radius of the arc.
     """)
 
-    start_angle = AngleSpec("start_angle", help="""
-    The angles to start the arcs, in radians, as measured from the horizontal.
+    start_angle = AngleSpec(help="""
+    The angles to start the arcs, as measured from the horizontal.
     """)
 
-    end_angle = AngleSpec("end_angle", help="""
-    The angles to end the arcs, in radians, as measured from the horizontal.
+    end_angle = AngleSpec(help="""
+    The angles to end the arcs, as measured from the horizontal.
     """)
 
-    direction = Enum(Direction, help="""
+    direction = Enum(Direction, default='anticlock', help="""
     Which direction to stroke between the start and end angles.
     """)
+
     line_props = Include(LineProps, use_prefix=False, help="""
     The %s values for the arcs.
     """)
@@ -157,46 +142,43 @@ class Bezier(Glyph):
     For more information consult the `Wikipedia article for Bézier curve`_.
 
     .. _Wikipedia article for Bézier curve: http://en.wikipedia.org/wiki/Bézier_curve
-
-    Example
-    -------
-
-    .. bokeh-plot:: ../tests/glyphs/Bezier.py
-        :source-position: none
-
-    *source:* `tests/glyphs/Bezier.py <https://github.com/bokeh/bokeh/tree/master/tests/glyphs/Bezier.py>`_
-
     """
 
-    x0 = NumberSpec("x0", help="""
+    __example__ = "tests/glyphs/Bezier.py"
+
+    # a canonical order for positional args that can be used for any
+    # functions derived from this class
+    _args = ('x0', 'y0', 'x1', 'y1', 'cx0', 'cy0', 'cx1', 'cy1')
+
+    x0 = NumberSpec(help="""
     The x-coordinates of the starting points.
     """)
 
-    y0 = NumberSpec("y0", help="""
+    y0 = NumberSpec(help="""
     The y-coordinates of the starting points.
     """)
 
-    x1 = NumberSpec("x1", help="""
+    x1 = NumberSpec(help="""
     The x-coordinates of the ending points.
     """)
 
-    y1 = NumberSpec("y1", help="""
+    y1 = NumberSpec(help="""
     The y-coordinates of the ending points.
     """)
 
-    cx0 = NumberSpec("cx0", help="""
+    cx0 = NumberSpec(help="""
     The x-coordinates of first control points.
     """)
 
-    cy0 = NumberSpec("cy0", help="""
+    cy0 = NumberSpec(help="""
     The y-coordinates of first control points.
     """)
 
-    cx1 = NumberSpec("cx1", help="""
+    cx1 = NumberSpec(help="""
     The x-coordinates of second control points.
     """)
 
-    cy1 = NumberSpec("cy1", help="""
+    cy1 = NumberSpec(help="""
     The y-coordinates of second control points.
     """)
 
@@ -204,6 +186,43 @@ class Bezier(Glyph):
     The %s values for the Bézier curves.
     """)
 
+class Ellipse(Glyph):
+    u""" Render ellipses. """
+
+    __example__ = "tests/glyphs/Ellipse.py"
+
+    # a canonical order for positional args that can be used for any
+    # functions derived from this class
+    _args = ('x', 'y', 'width', 'height', 'angle')
+
+    x = NumberSpec(help="""
+    The x-coordinates of the centers of the ellipses.
+    """)
+
+    y = NumberSpec(help="""
+    The y-coordinates of the centers of the ellipses.
+    """)
+
+    width = DistanceSpec(help="""
+    The widths of each ellipse.
+    """)
+
+    height = DistanceSpec(help="""
+    The heights of each ellipse.
+    """)
+
+    angle = AngleSpec(default=0.0, help="""
+    The angle the ellipses are rotated from horizontal. [rad]
+    """)
+
+    line_props = Include(LineProps, use_prefix=False, help="""
+    The %s values for the ovals.
+    """)
+
+    fill_props = Include(FillProps, use_prefix=False, help="""
+    The %s values for the ovals.
+    """)
+
 class Gear(Glyph):
     """ Render gears.
 
@@ -212,22 +231,19 @@ class Gear(Glyph):
     article for Gear`_.
 
     .. _Wikipedia article for Gear: http://en.wikipedia.org/wiki/Gear
-
-    Example
-    -------
-
-    .. bokeh-plot:: ../tests/glyphs/Gear.py
-        :source-position: none
-
-    *source:* `tests/glyphs/Gear.py <https://github.com/bokeh/bokeh/tree/master/tests/glyphs/Gear.py>`_
-
     """
 
-    x = NumberSpec("x", help="""
+    __example__ = "tests/glyphs/Gear.py"
+
+    # a canonical order for positional args that can be used for any
+    # functions derived from this class
+    _args = ('x', 'y', 'angle', 'module', 'teeth', 'pressure_angle', 'shaft_size', 'internal')
+
+    x = NumberSpec(help="""
     The x-coordinates of the center of the gears.
     """)
 
-    y = NumberSpec("y", help="""
+    y = NumberSpec(help="""
     The y-coordinates of the center of the gears.
     """)
 
@@ -235,7 +251,7 @@ class Gear(Glyph):
     The angle the gears are rotated from horizontal. [rad]
     """)
 
-    module = NumberSpec("module", help="""
+    module = NumberSpec(help="""
     A scaling factor, given by::
 
         m = p / pi
@@ -245,11 +261,11 @@ class Gear(Glyph):
     the same gear, measured along the pitch circle. [float]
     """)
 
-    teeth = NumberSpec("teeth", help="""
+    teeth = NumberSpec(help="""
     How many teeth the gears have. [int]
     """)
 
-    pressure_angle = NumberSpec(default=20, help= """
+    pressure_angle = NumberSpec(default=20, help="""
     The complement of the angle between the direction that the teeth
     exert force on each other, and the line joining the centers of the
     two gears. [deg]
@@ -275,10 +291,7 @@ class Gear(Glyph):
     """)
 
 class Image(Glyph):
-    """ Render images given as scalar data together with a color
-    mapper.
-
-    """
+    """ Render images given as scalar data together with a color mapper. """
 
     def __init__(self, **kwargs):
         if 'palette' in kwargs and 'color_mapper' in kwargs:
@@ -300,34 +313,36 @@ class Image(Glyph):
 
         super(Image, self).__init__(**kwargs)
 
-    image = NumberSpec("image", help="""
+    # a canonical order for positional args that can be used for any
+    # functions derived from this class
+    _args = ('image', 'x', 'y', 'dw', 'dh', 'dilate')
+
+    image = NumberSpec(help="""
     The arrays of scalar data for the images to be colormapped.
     """)
 
-    x = NumberSpec("x", help="""
+    x = NumberSpec(help="""
     The x-coordinates to locate the image anchors.
     """)
 
-    y = NumberSpec("y", help="""
+    y = NumberSpec(help="""
     The y-coordinates to locate the image anchors.
     """)
 
-    dw = DistanceSpec("dw", help="""
+    dw = DistanceSpec(help="""
     The widths of the plot regions that the images will occupy.
 
     .. note::
         This is not the number of pixels that an image is wide.
         That number is fixed by the image itself.
-
     """)
 
-    dh = DistanceSpec("dh", help="""
+    dh = DistanceSpec(help="""
     The height of the plot region that the image will occupy.
 
     .. note::
         This is not the number of pixels that an image is tall.
         That number is fixed by the image itself.
-
     """)
 
     dilate = Bool(False, help="""
@@ -336,62 +351,60 @@ class Image(Glyph):
 
     This setting may be useful if pixel rounding errors are causing
     images to have a gap between them, when they should appear flush.
-
     """)
 
-    color_mapper = Instance(LinearColorMapper, help="""
+    color_mapper = Instance(ColorMapper, help="""
     A ``ColorMapper`` to use to map the scalar data from ``image``
     into RGBA values for display.
 
     .. note::
         The color mapping step happens on the client.
-
     """)
 
     # TODO: (bev) support anchor property for Image
     # ref: https://github.com/bokeh/bokeh/issues/1763
 
 class ImageRGBA(Glyph):
-    """ Render images given as RGBA data.
+    """ Render images given as RGBA data. """
 
-    """
+    # a canonical order for positional args that can be used for any
+    # functions derived from this class
+    _args = ('image', 'x', 'y', 'dw', 'dh', 'dilate')
 
-    image = NumberSpec("image", help="""
+    image = NumberSpec(help="""
     The arrays of RGBA data for the images.
     """)
 
-    x = NumberSpec("x", help="""
+    x = NumberSpec(help="""
     The x-coordinates to locate the image anchors.
     """)
 
-    y = NumberSpec("y", help="""
+    y = NumberSpec(help="""
     The y-coordinates to locate the image anchors.
     """)
 
-    rows = NumberSpec("rows", help="""
+    rows = NumberSpec(None, help="""
     The numbers of rows in the images
     """)
 
-    cols = NumberSpec("cols", help="""
+    cols = NumberSpec(None, help="""
     The numbers of columns in the images
     """)
 
-    dw = DistanceSpec("dw", help="""
+    dw = DistanceSpec(help="""
     The widths of the plot regions that the images will occupy.
 
     .. note::
         This is not the number of pixels that an image is wide.
         That number is fixed by the image itself.
-
     """)
 
-    dh = DistanceSpec("dh", help="""
+    dh = DistanceSpec(help="""
     The height of the plot region that the image will occupy.
 
     .. note::
         This is not the number of pixels that an image is tall.
         That number is fixed by the image itself.
-
     """)
 
     dilate = Bool(False, help="""
@@ -406,37 +419,32 @@ class ImageRGBA(Glyph):
     # ref: https://github.com/bokeh/bokeh/issues/1763
 
 class ImageURL(Glyph):
-    """ Render images loaded from given URLs.
+    """ Render images loaded from given URLs. """
 
-    Example
-    -------
+    __example__ = "tests/glyphs/ImageURL.py"
 
-    .. bokeh-plot:: ../tests/glyphs/ImageURL.py
-        :source-position: none
+    # a canonical order for positional args that can be used for any
+    # functions derived from this class
+    _args = ('url', 'x', 'y', 'w', 'h', 'angle', 'global_alpha', 'dilate')
 
-    *source:* `tests/glyphs/ImageURL.py <https://github.com/bokeh/bokeh/tree/master/tests/glyphs/ImageURL.py>`_
-
-    """
-
-    url = NumberSpec("url", help="""
+    url = NumberSpec(help="""
     The URLs to retrieve images from.
 
     .. note::
         The actual retrieving and loading of the images happens on
         the client.
-
     """)
 
-    x = NumberSpec("x", help="""
+    x = NumberSpec(help="""
     The x-coordinates to locate the image anchors.
     """)
 
-    y = NumberSpec("y", help="""
+    y = NumberSpec(help="""
     The y-coordinates to locate the image anchors.
     """)
 
     # TODO: (bev) rename to "dw" for consistency
-    w = DistanceSpec("w", help="""
+    w = DistanceSpec(help="""
     The widths of the plot regions that the images will occupy.
 
     .. note::
@@ -445,11 +453,10 @@ class ImageURL(Glyph):
 
     .. note::
         This may be renamed to "dw" in the future.
-
     """)
 
     # TODO: (bev) rename to "dh" for consistency
-    h = DistanceSpec("h", help="""
+    h = DistanceSpec(help="""
     The height of the plot region that the image will occupy.
 
     .. note::
@@ -458,16 +465,15 @@ class ImageURL(Glyph):
 
     .. note::
         This may be renamed to "dh" in the future.
-
     """)
 
     angle = AngleSpec(default=0, help="""
-    The angles to rotate the images, in radians as measured from the
-    horizontal.
+    The angles to rotate the images, as measured from the horizontal.
     """)
 
     global_alpha = Float(1.0, help="""
-    The opacity that each image is rendered with.
+    An overall opacity that each image is rendered with (in addition
+    to any inherent alpha values in the image itself).
     """)
 
     dilate = Bool(False, help="""
@@ -483,28 +489,34 @@ class ImageURL(Glyph):
     coordinates.
     """)
 
+    retry_attempts = Int(0, help="""
+    Number of attempts to retry loading the images from the specified URL.
+    Default is zero.
+    """)
+
+    retry_timeout = Int(0, help="""
+    Timeout (in ms) between retry attempts to load the image from the
+    specified URL. Default is zero ms.
+    """)
+
 class Line(Glyph):
     """ Render a single line.
 
     .. note::
         The ``Line`` glyph is different from most other glyphs in that
         the vector of values only produces one glyph on the Plot.
-
-    Example
-    -------
-
-    .. bokeh-plot:: ../tests/glyphs/Line.py
-        :source-position: none
-
-    *source:* `tests/glyphs/Line.py <https://github.com/bokeh/bokeh/tree/master/tests/glyphs/Line.py>`_
-
     """
+    # a canonical order for positional args that can be used for any
+    # functions derived from this class
+    _args = ('x', 'y')
 
-    x = NumberSpec("x", help="""
+    __example__ = "tests/glyphs/Line.py"
+
+    x = NumberSpec(help="""
     The x-coordinates for the points of the line.
     """)
 
-    y = NumberSpec("y", help="""
+    y = NumberSpec(help="""
     The y-coordinates for the points of the line.
     """)
 
@@ -519,21 +531,19 @@ class MultiLine(Glyph):
         The data for the ``MultiLine`` glyph is different in that the
         vector of values is not a vector of scalars. Rather, it is a
         "list of lists".
-
-    Example
-    -------
-
-    .. bokeh-plot:: ../tests/glyphs/MultiLine.py
-        :source-position: none
-
-    *source:* `tests/glyphs/MultiLine.py <https://github.com/bokeh/bokeh/tree/master/tests/glyphs/MultiLine.py>`_
-
     """
-    xs = NumberSpec("xs", help="""
+
+    __example__ = "tests/glyphs/MultiLine.py"
+
+    # a canonical order for positional args that can be used for any
+    # functions derived from this class
+    _args = ('xs', 'ys')
+
+    xs = NumberSpec(help="""
     The x-coordinates for all the lines, given as a "list of lists".
     """)
 
-    ys = NumberSpec("ys", help="""
+    ys = NumberSpec(help="""
     The x-coordinates for all the lines, given as a "list of lists".
     """)
 
@@ -546,35 +556,33 @@ class Oval(Glyph):
 
     .. note::
         This glyph renders ovals using Bézier curves, which are similar,
-        but not identical to ellipses.
-
-    Example
-    -------
-
-    .. bokeh-plot:: ../tests/glyphs/Oval.py
-        :source-position: none
-
-    *source:* `tests/glyphs/Oval.py <https://github.com/bokeh/bokeh/tree/master/tests/glyphs/Oval.py>`_
-
+        but not identical to ellipses. In particular, widths equal to heights
+        will not render circles. Use the ``Ellipse`` glyph for that.
     """
 
-    x = NumberSpec("x", help="""
+    __example__ = "tests/glyphs/Oval.py"
+
+    # a canonical order for positional args that can be used for any
+    # functions derived from this class
+    _args = ('x', 'y', 'width', 'height', 'angle')
+
+    x = NumberSpec(help="""
     The x-coordinates of the centers of the ovals.
     """)
 
-    y = NumberSpec("y", help="""
+    y = NumberSpec(help="""
     The y-coordinates of the centers of the ovals.
     """)
 
-    width = DistanceSpec("width", help="""
+    width = DistanceSpec(help="""
     The overall widths of each oval.
     """)
 
-    height = DistanceSpec("height", help="""
+    height = DistanceSpec(help="""
     The overall height of each oval.
     """)
 
-    angle = AngleSpec("angle", help="""
+    angle = AngleSpec(default=0.0, help="""
     The angle the ovals are rotated from horizontal. [rad]
     """)
 
@@ -592,35 +600,30 @@ class Patch(Glyph):
     .. note::
         The ``Patch`` glyph is different from most other glyphs in that
         the vector of values only produces one glyph on the Plot.
-
-    Example
-    -------
-
-    .. bokeh-plot:: ../tests/glyphs/Patch.py
-        :source-position: none
-
-    *source:* `tests/glyphs/Patch.py <https://github.com/bokeh/bokeh/tree/master/tests/glyphs/Patch.py>`_
-
     """
 
-    x = NumberSpec("x", help="""
+    __example__ = "tests/glyphs/Patch.py"
+
+    # a canonical order for positional args that can be used for any
+    # functions derived from this class
+    _args = ('x', 'y')
+
+    x = NumberSpec(help="""
     The x-coordinates for the points of the patch.
 
     .. note::
         A patch may comprise multiple polygons. In this case the
         x-coordinates for each polygon should be separated by NaN
         values in the sequence.
-
     """)
 
-    y = NumberSpec("y", help="""
+    y = NumberSpec(help="""
     The y-coordinates for the points of the patch.
 
     .. note::
         A patch may comprise multiple polygons. In this case the
         y-coordinates for each polygon should be separated by NaN
         values in the sequence.
-
     """)
 
     line_props = Include(LineProps, use_prefix=False, help="""
@@ -638,35 +641,30 @@ class Patches(Glyph):
         The data for the ``Patches`` glyph is different in that the
         vector of values is not a vector of scalars. Rather, it is a
         "list of lists".
-
-    Example
-    -------
-
-    .. bokeh-plot:: ../tests/glyphs/Patches.py
-        :source-position: none
-
-    *source:* `tests/glyphs/Patches.py <https://github.com/bokeh/bokeh/tree/master/tests/glyphs/Patches.py>`_
-
     """
 
-    xs = NumberSpec("xs", help="""
+    __example__ = "tests/glyphs/Patches.py"
+
+    # a canonical order for positional args that can be used for any
+    # functions derived from this class
+    _args = ('xs', 'ys')
+
+    xs = NumberSpec(help="""
     The x-coordinates for all the patches, given as a "list of lists".
 
     .. note::
         Individual patches may comprise multiple polygons. In this case
         the x-coordinates for each polygon should be separated by NaN
         values in the sublists.
-
     """)
 
-    ys = NumberSpec("ys", help="""
+    ys = NumberSpec(help="""
     The y-coordinates for all the patches, given as a "list of lists".
 
     .. note::
         Individual patches may comprise multiple polygons. In this case
         the y-coordinates for each polygon should be separated by NaN
         values in the sublists.
-
     """)
 
     line_props = Include(LineProps, use_prefix=False, help="""
@@ -678,31 +676,27 @@ class Patches(Glyph):
     """)
 
 class Quad(Glyph):
-    """ Render axis-aligned quads.
+    """ Render axis-aligned quads. """
 
-    Example
-    -------
+    __example__ = "tests/glyphs/Quad.py"
 
-    .. bokeh-plot:: ../tests/glyphs/Quad.py
-        :source-position: none
+    # a canonical order for positional args that can be used for any
+    # functions derived from this class
+    _args = ('left', 'right', 'top', 'bottom')
 
-    *source:* `tests/glyphs/Quad.py <https://github.com/bokeh/bokeh/tree/master/tests/glyphs/Quad.py>`_
-
-    """
-
-    left = NumberSpec("left", help="""
+    left = NumberSpec(help="""
     The x-coordinates of the left edges.
     """)
 
-    right = NumberSpec("right", help="""
+    right = NumberSpec(help="""
     The x-coordinates of the right edges.
     """)
 
-    bottom = NumberSpec("bottom", help="""
+    bottom = NumberSpec(help="""
     The y-coordinates of the bottom edges.
     """)
 
-    top = NumberSpec("top", help="""
+    top = NumberSpec(help="""
     The y-coordinates of the top edges.
     """)
 
@@ -715,39 +709,35 @@ class Quad(Glyph):
     """)
 
 class Quadratic(Glyph):
-    """ Render parabolas.
+    """ Render parabolas. """
 
-    Example
-    -------
+    __example__ = "tests/glyphs/Quadratic.py"
 
-    .. bokeh-plot:: ../tests/glyphs/Quadratic.py
-        :source-position: none
+    # a canonical order for positional args that can be used for any
+    # functions derived from this class
+    _args = ('x0', 'y0', 'x1', 'y1', 'cx', 'cy')
 
-    *source:* `tests/glyphs/Quadratic.py <https://github.com/bokeh/bokeh/tree/master/tests/glyphs/Quadratic.py>`_
-
-    """
-
-    x0 = NumberSpec("x0", help="""
+    x0 = NumberSpec(help="""
     The x-coordinates of the starting points.
     """)
 
-    y0 = NumberSpec("y0", help="""
+    y0 = NumberSpec(help="""
     The y-coordinates of the starting points.
     """)
 
-    x1 = NumberSpec("x1", help="""
+    x1 = NumberSpec(help="""
     The x-coordinates of the ending points.
     """)
 
-    y1 = NumberSpec("y1", help="""
+    y1 = NumberSpec(help="""
     The y-coordinates of the ending points.
     """)
 
-    cx = NumberSpec("cx", help="""
+    cx = NumberSpec(help="""
     The x-coordinates of the control points.
     """)
 
-    cy = NumberSpec("cy", help="""
+    cy = NumberSpec(help="""
     The y-coordinates of the control points.
     """)
 
@@ -756,32 +746,27 @@ class Quadratic(Glyph):
     """)
 
 class Ray(Glyph):
-    """ Render rays.
+    """ Render rays. """
 
-    Example
-    -------
+    __example__ = "tests/glyphs/Ray.py"
 
-    .. bokeh-plot:: ../tests/glyphs/Ray.py
-        :source-position: none
+    # a canonical order for positional args that can be used for any
+    # functions derived from this class
+    _args = ('x', 'y', 'length', 'angle')
 
-    *source:* `tests/glyphs/Ray.py <https://github.com/bokeh/bokeh/tree/master/tests/glyphs/Ray.py>`_
-
-    """
-
-    x = NumberSpec("x", help="""
+    x = NumberSpec(help="""
     The x-coordinates to start the rays.
     """)
 
-    y = NumberSpec("y", help="""
+    y = NumberSpec(help="""
     The y-coordinates to start the rays.
     """)
 
-    angle = AngleSpec("angle", help="""
-    The angles in radians to extend the rays, as measured from the
-    horizontal.
+    angle = AngleSpec(help="""
+    The angles in radians to extend the rays, as measured from the horizontal.
     """)
 
-    length = DistanceSpec("length", help="""
+    length = DistanceSpec(help="""
     The length to extend the ray. Note that this ``length`` defaults
     to screen units.
     """)
@@ -791,37 +776,32 @@ class Ray(Glyph):
     """)
 
 class Rect(Glyph):
-    """ Render rectangles.
+    """ Render rectangles. """
 
-    Example
-    -------
+    __example__ = "tests/glyphs/Rect.py"
 
-    .. bokeh-plot:: ../tests/glyphs/Rect.py
-        :source-position: none
+    # a canonical order for positional args that can be used for any
+    # functions derived from this class
+    _args = ('x', 'y', 'width', 'height', 'angle', 'dilate')
 
-    *source:* `tests/glyphs/Rect.py <https://github.com/bokeh/bokeh/tree/master/tests/glyphs/Rect.py>`_
-
-    """
-
-    x = NumberSpec("x", help="""
+    x = NumberSpec(help="""
     The x-coordinates of the centers of the rectangles.
     """)
 
-    y = NumberSpec("y", help="""
+    y = NumberSpec(help="""
     The y-coordinates of the centers of the rectangles.
     """)
 
-    width = DistanceSpec("width", help="""
+    width = DistanceSpec(help="""
     The overall widths of the rectangles.
     """)
 
-    height = DistanceSpec("height", help="""
+    height = DistanceSpec(help="""
     The overall heights of the rectangles.
     """)
 
-    angle = AngleSpec("angle", help="""
-    The angles to rotate the rectangles, in radians, as measured from
-    the horizontal.
+    angle = AngleSpec(default=0.0, help="""
+    The angles to rotate the rectangles, as measured from the horizontal.
     """)
 
     dilate = Bool(False, help="""
@@ -842,31 +822,27 @@ class Rect(Glyph):
     """)
 
 class Segment(Glyph):
-    """ Render segments.
+    """ Render segments. """
 
-    Example
-    -------
+    __example__ = "tests/glyphs/Segment.py"
 
-    .. bokeh-plot:: ../tests/glyphs/Segment.py
-        :source-position: none
+    # a canonical order for positional args that can be used for any
+    # functions derived from this class
+    _args = ('x0', 'y0', 'x1', 'y1')
 
-    *source:* `tests/glyphs/Segment.py <https://github.com/bokeh/bokeh/tree/master/tests/glyphs/Segment.py>`_
-
-    """
-
-    x0 = NumberSpec("x0", help="""
+    x0 = NumberSpec(help="""
     The x-coordinates of the starting points.
     """)
 
-    y0 = NumberSpec("y0", help="""
+    y0 = NumberSpec(help="""
     The y-coordinates of the starting points.
     """)
 
-    x1 = NumberSpec("x1", help="""
+    x1 = NumberSpec(help="""
     The x-coordinates of the ending points.
     """)
 
-    y1 = NumberSpec("y1", help="""
+    y1 = NumberSpec(help="""
     The y-coordinates of the ending points.
     """)
 
@@ -875,23 +851,19 @@ class Segment(Glyph):
     """)
 
 class Text(Glyph):
-    """ Render text.
+    """ Render text. """
 
-    Example
-    -------
+    __example__ = "tests/glyphs/Text.py"
 
-    .. bokeh-plot:: ../tests/glyphs/Text.py
-        :source-position: none
+    # a canonical order for positional args that can be used for any
+    # functions derived from this class
+    _args = ('x', 'y', 'text', 'angle', 'x_offset', 'y_offset')
 
-    *source:* `tests/glyphs/Text.py <https://github.com/bokeh/bokeh/tree/master/tests/glyphs/Text.py>`_
-
-    """
-
-    x = NumberSpec("x", help="""
+    x = NumberSpec(help="""
     The x-coordinates to locate the text anchors.
     """)
 
-    y = NumberSpec("y", help="""
+    y = NumberSpec(help="""
     The y-coordinates to locate the text anchors.
     """)
 
@@ -900,7 +872,7 @@ class Text(Glyph):
     """)
 
     angle = AngleSpec(default=0, help="""
-    The angles to rotate the text, in radians,, as measured from the horizontal.
+    The angles to rotate the text, as measured from the horizontal.
     """)
 
     x_offset = NumberSpec(default=0, help="""
@@ -923,38 +895,35 @@ class Text(Glyph):
 
 class Wedge(Glyph):
     """ Render wedges.
-
-    Example
-    -------
-
-    .. bokeh-plot:: ../tests/glyphs/Wedge.py
-        :source-position: none
-
-    *source:* `tests/glyphs/Wedge.py <https://github.com/bokeh/bokeh/tree/master/tests/glyphs/Wedge.py>`_
-
     """
 
-    x = NumberSpec("x", help="""
+    __example__ = "tests/glyphs/Wedge.py"
+
+    # a canonical order for positional args that can be used for any
+    # functions derived from this class
+    _args = ('x', 'y', 'radius', 'start_angle', 'end_angle', 'direction')
+
+    x = NumberSpec(help="""
     The x-coordinates of the points of the wedges.
     """)
 
-    y = NumberSpec("y", help="""
+    y = NumberSpec(help="""
     The y-coordinates of the points of the wedges.
     """)
 
-    radius = DistanceSpec("radius", help="""
+    radius = DistanceSpec(help="""
     Radii of the wedges.
     """)
 
-    start_angle = AngleSpec("start_angle", help="""
-    The angles to start the wedges, in radians, as measured from the horizontal.
+    start_angle = AngleSpec(help="""
+    The angles to start the wedges, as measured from the horizontal.
     """)
 
-    end_angle = AngleSpec("end_angle", help="""
-    The angles to end the wedges, in radians as measured from the horizontal.
+    end_angle = AngleSpec(help="""
+    The angles to end the wedges, as measured from the horizontal.
     """)
 
-    direction = Enum(Direction, help="""
+    direction = Enum(Direction, default='anticlock', help="""
     Which direction to stroke between the start and end angles.
     """)
 
