@@ -1,5 +1,5 @@
-
 from bokeh.models import HoverTool
+from bokeh.palettes import Viridis6
 from bokeh.plotting import figure, show, output_file, ColumnDataSource
 from bokeh.sampledata.us_counties import data as counties
 from bokeh.sampledata.unemployment import data as unemployment
@@ -11,11 +11,9 @@ counties = {
 county_xs = [county["lons"] for county in counties.values()]
 county_ys = [county["lats"] for county in counties.values()]
 
-colors = ["#F1EEF6", "#D4B9DA", "#C994C7", "#DF65B0", "#DD1C77", "#980043"]
-
 county_names = [county['name'] for county in counties.values()]
 county_rates = [unemployment[county_id] for county_id in counties]
-county_colors = [colors[int(rate/3)] for rate in county_rates]
+county_colors = [Viridis6[int(rate/3)] for rate in county_rates]
 
 source = ColumnDataSource(data=dict(
     x=county_xs,
@@ -27,7 +25,9 @@ source = ColumnDataSource(data=dict(
 
 TOOLS="pan,wheel_zoom,box_zoom,reset,hover,save"
 
-p = figure(title="Texas Unemployment 2009", tools=TOOLS)
+p = figure(title="Texas Unemployment 2009", tools=TOOLS,
+           x_axis_location=None, y_axis_location=None)
+p.grid.grid_line_color = None
 
 p.patches('x', 'y', source=source,
           fill_color='color', fill_alpha=0.7,
